==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/ug.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'ug', {
	border: 'گىرۋەك',
	caption: 'ماۋزۇ',
	cell: {
		menu: 'كاتەكچە',
		insertBefore: 'سولغا كاتەكچە قىستۇر',
		insertAfter: 'ئوڭغا كاتەكچە قىستۇر',
		deleteCell: 'كەتەكچە ئۆچۈر',
		merge: 'كاتەكچە بىرلەشتۈر',
		mergeRight: 'كاتەكچىنى ئوڭغا بىرلەشتۈر',
		mergeDown: 'كاتەكچىنى ئاستىغا بىرلەشتۈر',
		splitHorizontal: 'كاتەكچىنى توغرىسىغا بىرلەشتۈر',
		splitVertical: 'كاتەكچىنى بويىغا بىرلەشتۈر',
		title: 'كاتەكچە خاسلىقى',
		cellType: 'كاتەكچە تىپى',
		rowSpan: 'بويىغا چات ئارىسى قۇر سانى',
		colSpan: 'توغرىسىغا چات ئارىسى ئىستون سانى',
		wordWrap: 'ئۆزلۈكىدىن قۇر قاتلا',
		hAlign: 'توغرىسىغا توغرىلا',
		vAlign: 'بويىغا توغرىلا',
		alignBaseline: 'ئاساسىي سىزىق',
		bgColor: 'تەگلىك رەڭگى',
		borderColor: 'گىرۋەك رەڭگى',
		data: 'سانلىق مەلۇمات',
		header: 'جەدۋەل باشى',
		yes: 'ھەئە',
		no: 'ياق',
		invalidWidth: 'كاتەكچە كەڭلىكى چوقۇم سان بولىدۇ',
		invalidHeight: 'كاتەكچە ئېگىزلىكى چوقۇم سان بولىدۇ',
		invalidRowSpan: 'قۇر چات ئارىسى چوقۇم پۈتۈن سان بولىدۇ ',
		invalidColSpan: 'ئىستون چات ئارىسى چوقۇم پۈتۈن سان بولىدۇ',
		chooseColor: 'تاللاڭ'
	},
	cellPad: 'يان ئارىلىق',
	cellSpace: 'ئارىلىق',
	column: {
		menu: 'ئىستون',
		insertBefore: 'سولغا ئىستون قىستۇر',
		insertAfter: 'ئوڭغا ئىستون قىستۇر',
		deleteColumn: 'ئىستون ئۆچۈر'
	},
	columns: 'ئىستون سانى',
	deleteTable: 'جەدۋەل ئۆچۈر',
	headers: 'ماۋزۇ كاتەكچە',
	headersBoth: 'بىرىنچى ئىستون ۋە بىرىنچى قۇر',
	headersColumn: 'بىرىنچى ئىستون',
	headersNone: 'يوق',
	headersRow: 'بىرىنچى قۇر',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'گىرۋەك توملۇقى چوقۇم سان بولىدۇ',
	invalidCellPadding: 'كاتەكچىگە چوقۇم سان تولدۇرۇلىدۇ',
	invalidCellSpacing: 'كاتەكچە ئارىلىقى چوقۇم سان بولىدۇ',
	invalidCols: 'بەلگىلەنگەن قۇر سانى چوقۇم نۆلدىن چوڭ بولىدۇ',
	invalidHeight: 'جەدۋەل ئېگىزلىكى چوقۇم سان بولىدۇ',
	invalidRows: 'بەلگىلەنگەن ئىستون سانى چوقۇم نۆلدىن چوڭ بولىدۇ',
	invalidWidth: 'جەدۋەل كەڭلىكى چوقۇم سان بولىدۇ',
	menu: 'جەدۋەل خاسلىقى',
	row: {
		menu: 'قۇر',
		insertBefore: 'ئۈستىگە قۇر قىستۇر',
		insertAfter: 'ئاستىغا قۇر قىستۇر',
		deleteRow: 'قۇر ئۆچۈر'
	},
	rows: 'قۇر سانى',
	summary: 'ئۈزۈندە',
	title: 'جەدۋەل خاسلىقى',
	toolbar: 'جەدۋەل',
	widthPc: 'پىرسەنت',
	widthPx: 'پىكسېل',
	widthUnit: 'كەڭلىك بىرلىكى'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/ug.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'ug', {
	border: 'گىرۋەك',
	caption: 'ماۋزۇ',
	cell: {
		menu: 'كاتەكچە',
		insertBefore: 'سولغا كاتەكچە قىستۇر',
		insertAfter: 'ئوڭغا كاتەكچە قىستۇر',
		deleteCell: 'كەتەكچە ئۆچۈر',
		merge: 'كاتەكچە بىرلەشتۈر',
		mergeRight: 'كاتەكچىنى ئوڭغا بىرلەشتۈر',
		mergeDown: 'كاتەكچىنى ئاستىغا بىرلەشتۈر',
		splitHorizontal: 'كاتەكچىنى توغرىسىغا بىرلەشتۈر',
		splitVertical: 'كاتەكچىنى بويىغا بىرلەشتۈر',
		title: 'كاتەكچە خاسلىقى',
		cellType: 'كاتەكچە تىپى',
		rowSpan: 'بويىغا چات ئارىسى قۇر سانى',
		colSpan: 'توغرىسىغا چات ئارىسى ئىستون سانى',
		wordWrap: 'ئۆزلۈكىدىن قۇر قاتلا',
		hAlign: 'توغرىسىغا توغرىلا',
		vAlign: 'بويىغا توغرىلا',
		alignBaseline: 'ئاساسىي سىزىق',
		bgColor: 'تەگلىك رەڭگى',
		borderColor: 'گىرۋەك رەڭگى',
		data: 'سانلىق مەلۇمات',
		header: 'جەدۋەل باشى',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'ھەئە',
		no: 'ياق',
		invalidWidth: 'كاتەكچە كەڭلىكى چوقۇم سان بولىدۇ',
		invalidHeight: 'كاتەكچە ئېگىزلىكى چوقۇم سان بولىدۇ',
		invalidRowSpan: 'قۇر چات ئارىسى چوقۇم پۈتۈن سان بولىدۇ ',
		invalidColSpan: 'ئىستون چات ئارىسى چوقۇم پۈتۈن سان بولىدۇ',
		chooseColor: 'تاللاڭ'
	},
	cellPad: 'يان ئارىلىق',
	cellSpace: 'ئارىلىق',
	column: {
		menu: 'ئىستون',
		insertBefore: 'سولغا ئىستون قىستۇر',
		insertAfter: 'ئوڭغا ئىستون قىستۇر',
		deleteColumn: 'ئىستون ئۆچۈر'
	},
	columns: 'ئىستون سانى',
	deleteTable: 'جەدۋەل ئۆچۈر',
	headers: 'ماۋزۇ كاتەكچە',
	headersBoth: 'بىرىنچى ئىستون ۋە بىرىنچى قۇر',
	headersColumn: 'بىرىنچى ئىستون',
	headersNone: 'يوق',
	headersRow: 'بىرىنچى قۇر',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'گىرۋەك توملۇقى چوقۇم سان بولىدۇ',
	invalidCellPadding: 'كاتەكچىگە چوقۇم سان تولدۇرۇلىدۇ',
	invalidCellSpacing: 'كاتەكچە ئارىلىقى چوقۇم سان بولىدۇ',
	invalidCols: 'بەلگىلەنگەن قۇر سانى چوقۇم نۆلدىن چوڭ بولىدۇ',
	invalidHeight: 'جەدۋەل ئېگىزلىكى چوقۇم سان بولىدۇ',
	invalidRows: 'بەلگىلەنگەن ئىستون سانى چوقۇم نۆلدىن چوڭ بولىدۇ',
	invalidWidth: 'جەدۋەل كەڭلىكى چوقۇم سان بولىدۇ',
	menu: 'جەدۋەل خاسلىقى',
	row: {
		menu: 'قۇر',
		insertBefore: 'ئۈستىگە قۇر قىستۇر',
		insertAfter: 'ئاستىغا قۇر قىستۇر',
		deleteRow: 'قۇر ئۆچۈر'
	},
	rows: 'قۇر سانى',
	summary: 'ئۈزۈندە',
	title: 'جەدۋەل خاسلىقى',
	toolbar: 'جەدۋەل',
	widthPc: 'پىرسەنت',
	widthPx: 'پىكسېل',
	widthUnit: 'كەڭلىك بىرلىكى'
} );
